@@ -105,8 +105,8 @@ BOOL LASreaderPLY::open(FILE* file, const CHAR* file_name, U8 point_type, BOOL p
   header.number_of_point_records = (npoints > U32_MAX ? 0 : (U32)npoints);
   header.extended_number_of_point_records = npoints;
 
-  sprintf(header.system_identifier, "LAStools (c) by rapidlasso GmbH");
-  sprintf(header.generating_software, "via LASreaderPLY (%d)", LAS_TOOLS_VERSION);
+  snprintf(header.system_identifier, 32, "LAStools (c) by rapidlasso GmbH");
+  snprintf(header.generating_software, 32, "via LASreaderPLY (%d)", LAS_TOOLS_VERSION);
 
   // maybe set creation date
 
@@ -562,7 +562,7 @@ void LASreaderPLY::add_attribute(I32 attribute_type, const char* name, const cha
   else
   {
     char temp[32];
-    sprintf(temp, "attribute %d", number_attributes);
+    snprintf(temp, 32, "attribute %d", number_attributes);
     attribute_names[number_attributes] = LASCopyString(temp);
   }
   if (description)
