@@ -745,7 +745,7 @@ void LASbin::add(F64 item, F64 value)
 static void lidardouble2string(CHAR* string, F64 value)
 {
   int len;
-  len = sprintf(string, "%.15f", value) - 1;
+  len = snprintf(string, 4096, "%.15f", value) - 1;
   while (string[len] == '0') len--;
   if (string[len] != '.') len++;
   string[len] = '\0';
@@ -754,23 +754,23 @@ static void lidardouble2string(CHAR* string, F64 value)
 static void lidardouble2string(CHAR* string, F64 value, F64 precision)
 {
   if (precision == 0.1 || precision == 0.2 || precision == 0.3 || precision == 0.4 || precision == 0.5)
-    sprintf(string, "%.1f", value);
+    snprintf(string, 4096, "%.1f", value);
   else if (precision == 0.01 || precision == 0.02 || precision == 0.03 || precision == 0.04 || precision == 0.05 || precision == 0.25)
-    sprintf(string, "%.2f", value);
+    snprintf(string, 4096, "%.2f", value);
   else if (precision == 0.001 || precision == 0.002 || precision == 0.003 || precision == 0.004 || precision == 0.005 || precision == 0.025 || precision == 0.125)
-    sprintf(string, "%.3f", value);
+    snprintf(string, 4096, "%.3f", value);
   else if (precision == 0.0001 || precision == 0.0002 || precision == 0.0005 || precision == 0.0025 || precision == 0.0125)
-    sprintf(string, "%.4f", value);
+    snprintf(string, 4096, "%.4f", value);
   else if (precision == 0.00001 || precision == 0.00002 || precision == 0.00005 || precision == 0.00025 || precision == 0.00125)
-    sprintf(string, "%.5f", value);
+    snprintf(string, 4096, "%.5f", value);
   else if (precision == 0.000001 || precision == 0.000002 || precision == 0.000005 || precision == 0.000025 || precision == 0.000125)
-    sprintf(string, "%.6f", value);
+    snprintf(string, 4096, "%.6f", value);
   else if (precision == 0.0000001)
-    sprintf(string, "%.7f", value);
+    snprintf(string, 4096, "%.7f", value);
   else if (precision == 0.00000001)
-    sprintf(string, "%.8f", value);
+    snprintf(string, 4096, "%.8f", value);
   else if (precision == 0.000000001)
-    sprintf(string, "%.9f", value);
+    snprintf(string, 4096, "%.9f", value);
   else
     lidardouble2string(string, value);
 }
@@ -1029,40 +1029,40 @@ BOOL LAShistogram::parse(int argc, char* argv[])
 I32 LAShistogram::unparse(CHAR* string) const
 {
   I32 n = 0;
-  if (x_bin) n += sprintf(&string[n], "-histo x %lf ", x_bin->get_step());
-  if (y_bin) n += sprintf(&string[n], "-histo y %lf ", y_bin->get_step());
-  if (z_bin) n += sprintf(&string[n], "-histo z %lf ", z_bin->get_step());
-  if (X_bin) n += sprintf(&string[n], "-histo X %lf ", X_bin->get_step());
-  if (Y_bin) n += sprintf(&string[n], "-histo Y %lf ", Y_bin->get_step());
-  if (Z_bin) n += sprintf(&string[n], "-histo Z %lf ", Z_bin->get_step());
-  if (intensity_bin) n += sprintf(&string[n], "-histo intensity %lf ", intensity_bin->get_step());
-  if (classification_bin) n += sprintf(&string[n], "-histo classification %lf ", classification_bin->get_step());
-  if (scan_angle_bin) n += sprintf(&string[n], "-histo scan_angle %lf ", scan_angle_bin->get_step());
-  if (extended_scan_angle_bin) n += sprintf(&string[n], "-histo extended_scan_angle %lf ", extended_scan_angle_bin->get_step());
-  if (return_number_bin) n += sprintf(&string[n], "-histo return_number %lf ", return_number_bin->get_step());
-  if (number_of_returns_bin) n += sprintf(&string[n], "-histo number_of_returns %lf ", number_of_returns_bin->get_step());
-  if (user_data_bin) n += sprintf(&string[n], "-histo user_data %lf ", user_data_bin->get_step());
-  if (point_source_id_bin) n += sprintf(&string[n], "-histo point_source %lf ", point_source_id_bin->get_step());
-  if (gps_time_bin) n += sprintf(&string[n], "-histo gps_time %lf ", gps_time_bin->get_step());
-  if (scanner_channel_bin) n += sprintf(&string[n], "-histo scanner_channel %lf ", scanner_channel_bin->get_step());
-  if (R_bin) n += sprintf(&string[n], "-histo R %lf ", R_bin->get_step());
-  if (G_bin) n += sprintf(&string[n], "-histo G %lf ", G_bin->get_step());
-  if (B_bin) n += sprintf(&string[n], "-histo B %lf ", B_bin->get_step());
-  if (I_bin) n += sprintf(&string[n], "-histo I %lf ", I_bin->get_step());
-  if (attribute0_bin) n += sprintf(&string[n], "-histo attribute0 %lf ", attribute0_bin->get_step());
-  if (attribute1_bin) n += sprintf(&string[n], "-histo attribute1 %lf ", attribute1_bin->get_step());
-  if (attribute2_bin) n += sprintf(&string[n], "-histo attribute2 %lf ", attribute2_bin->get_step());
-  if (attribute3_bin) n += sprintf(&string[n], "-histo attribute3 %lf ", attribute3_bin->get_step());
-  if (attribute4_bin) n += sprintf(&string[n], "-histo attribute4 %lf ", attribute4_bin->get_step());
-  if (attribute5_bin) n += sprintf(&string[n], "-histo attribute5 %lf ", attribute5_bin->get_step());
-  if (attribute6_bin) n += sprintf(&string[n], "-histo attribute6 %lf ", attribute6_bin->get_step());
-  if (attribute7_bin) n += sprintf(&string[n], "-histo attribute7 %lf ", attribute7_bin->get_step());
-  if (attribute8_bin) n += sprintf(&string[n], "-histo attribute8 %lf ", attribute8_bin->get_step());
-  if (attribute9_bin) n += sprintf(&string[n], "-histo attribute9 %lf ", attribute9_bin->get_step());
-  if (wavepacket_index_bin) n += sprintf(&string[n], "-histo wavepacket_index %lf ", wavepacket_index_bin->get_step());
-  if (wavepacket_offset_bin) n += sprintf(&string[n], "-histo wavepacket_offset %lf ", wavepacket_offset_bin->get_step());
-  if (wavepacket_size_bin) n += sprintf(&string[n], "-histo wavepacket_size %lf ", wavepacket_size_bin->get_step());
-  if (wavepacket_location_bin) n += sprintf(&string[n], "-histo wavepacket_location %lf ", wavepacket_location_bin->get_step());
+  if (x_bin) n += snprintf(&string[n], 0, "-histo x %lf ", x_bin->get_step());
+  if (y_bin) n += snprintf(&string[n], 0, "-histo y %lf ", y_bin->get_step());
+  if (z_bin) n += snprintf(&string[n], 0, "-histo z %lf ", z_bin->get_step());
+  if (X_bin) n += snprintf(&string[n], 0, "-histo X %lf ", X_bin->get_step());
+  if (Y_bin) n += snprintf(&string[n], 0, "-histo Y %lf ", Y_bin->get_step());
+  if (Z_bin) n += snprintf(&string[n], 0, "-histo Z %lf ", Z_bin->get_step());
+  if (intensity_bin) n += snprintf(&string[n], 0, "-histo intensity %lf ", intensity_bin->get_step());
+  if (classification_bin) n += snprintf(&string[n], 0, "-histo classification %lf ", classification_bin->get_step());
+  if (scan_angle_bin) n += snprintf(&string[n], 0, "-histo scan_angle %lf ", scan_angle_bin->get_step());
+  if (extended_scan_angle_bin) n += snprintf(&string[n], 0, "-histo extended_scan_angle %lf ", extended_scan_angle_bin->get_step());
+  if (return_number_bin) n += snprintf(&string[n], 0, "-histo return_number %lf ", return_number_bin->get_step());
+  if (number_of_returns_bin) n += snprintf(&string[n], 0, "-histo number_of_returns %lf ", number_of_returns_bin->get_step());
+  if (user_data_bin) n += snprintf(&string[n], 0, "-histo user_data %lf ", user_data_bin->get_step());
+  if (point_source_id_bin) n += snprintf(&string[n], 0, "-histo point_source %lf ", point_source_id_bin->get_step());
+  if (gps_time_bin) n += snprintf(&string[n], 0, "-histo gps_time %lf ", gps_time_bin->get_step());
+  if (scanner_channel_bin) n += snprintf(&string[n], 0, "-histo scanner_channel %lf ", scanner_channel_bin->get_step());
+  if (R_bin) n += snprintf(&string[n], 0, "-histo R %lf ", R_bin->get_step());
+  if (G_bin) n += snprintf(&string[n], 0, "-histo G %lf ", G_bin->get_step());
+  if (B_bin) n += snprintf(&string[n], 0, "-histo B %lf ", B_bin->get_step());
+  if (I_bin) n += snprintf(&string[n], 0, "-histo I %lf ", I_bin->get_step());
+  if (attribute0_bin) n += snprintf(&string[n], 0, "-histo attribute0 %lf ", attribute0_bin->get_step());
+  if (attribute1_bin) n += snprintf(&string[n], 0, "-histo attribute1 %lf ", attribute1_bin->get_step());
+  if (attribute2_bin) n += snprintf(&string[n], 0, "-histo attribute2 %lf ", attribute2_bin->get_step());
+  if (attribute3_bin) n += snprintf(&string[n], 0, "-histo attribute3 %lf ", attribute3_bin->get_step());
+  if (attribute4_bin) n += snprintf(&string[n], 0, "-histo attribute4 %lf ", attribute4_bin->get_step());
+  if (attribute5_bin) n += snprintf(&string[n], 0, "-histo attribute5 %lf ", attribute5_bin->get_step());
+  if (attribute6_bin) n += snprintf(&string[n], 0, "-histo attribute6 %lf ", attribute6_bin->get_step());
+  if (attribute7_bin) n += snprintf(&string[n], 0, "-histo attribute7 %lf ", attribute7_bin->get_step());
+  if (attribute8_bin) n += snprintf(&string[n], 0, "-histo attribute8 %lf ", attribute8_bin->get_step());
+  if (attribute9_bin) n += snprintf(&string[n], 0, "-histo attribute9 %lf ", attribute9_bin->get_step());
+  if (wavepacket_index_bin) n += snprintf(&string[n], 0, "-histo wavepacket_index %lf ", wavepacket_index_bin->get_step());
+  if (wavepacket_offset_bin) n += snprintf(&string[n], 0, "-histo wavepacket_offset %lf ", wavepacket_offset_bin->get_step());
+  if (wavepacket_size_bin) n += snprintf(&string[n], 0, "-histo wavepacket_size %lf ", wavepacket_size_bin->get_step());
+  if (wavepacket_location_bin) n += snprintf(&string[n], 0, "-histo wavepacket_location %lf ", wavepacket_location_bin->get_step());
   return n;
 }
 
