@@ -129,7 +129,7 @@ BOOL LASwriterWRL::open(FILE* file, const LASheader* header, const CHAR* parse_s
 static void lidardouble2string(CHAR* string, double value)
 {
   int len;
-  len = sprintf(string, "%.15f", value) - 1;
+  len = snprintf(string, 4096, "%.15f", value) - 1;
   while (string[len] == '0') len--;
   if (string[len] != '.') len++;
   string[len] = '\0';
@@ -138,23 +138,23 @@ static void lidardouble2string(CHAR* string, double value)
 static void lidardouble2string(CHAR* string, double value, double precision)
 {
   if (precision == 0.1)
-    sprintf(string, "%.1f", value);
+    snprintf(string, 4096, "%.1f", value);
   else if (precision == 0.01)
-    sprintf(string, "%.2f", value);
+    snprintf(string, 4096, "%.2f", value);
   else if (precision == 0.001)
-    sprintf(string, "%.3f", value);
+    snprintf(string, 4096, "%.3f", value);
   else if (precision == 0.0001)
-    sprintf(string, "%.4f", value);
+    snprintf(string, 4096, "%.4f", value);
   else if (precision == 0.00001)
-    sprintf(string, "%.5f", value);
+    snprintf(string, 4096, "%.5f", value);
   else if (precision == 0.000001)
-    sprintf(string, "%.6f", value);
+    snprintf(string, 4096, "%.6f", value);
   else if (precision == 0.0000001)
-    sprintf(string, "%.7f", value);
+    snprintf(string, 4096, "%.7f", value);
   else if (precision == 0.00000001)
-    sprintf(string, "%.8f", value);
+    snprintf(string, 4096, "%.8f", value);
   else if (precision == 0.000000001)
-    sprintf(string, "%.9f", value);
+    snprintf(string, 4096, "%.9f", value);
   else
     lidardouble2string(string, value);
 }
