@@ -508,17 +508,17 @@ BOOL LASreadPoint::read(U8* const * point)
       // end-of-file
       if (dec)
       {
-        sprintf(last_error, "end-of-file during chunk with index %u", current_chunk);
+        snprintf(last_error, 128, "end-of-file during chunk with index %u", current_chunk);
       }
       else
       {
-        sprintf(last_error, "end-of-file");
+        snprintf(last_error, 128, "end-of-file");
       }
     }
     else
     {
       // decompression error
-      sprintf(last_error, "chunk with index %u of %u is corrupt", current_chunk, tabled_chunks);
+      snprintf(last_error, 128, "chunk with index %u of %u is corrupt", current_chunk, tabled_chunks);
       // if we know where the next chunk starts ...
       if ((current_chunk+1) < tabled_chunks)
       {
@@ -550,7 +550,7 @@ BOOL LASreadPoint::check_end()
           // create error string
           if (last_error == 0) last_error = new CHAR[128];
           // report error
-          sprintf(last_error, "chunk with index %u of %u is corrupt", current_chunk, tabled_chunks);
+          snprintf(last_error, 128, "chunk with index %u of %u is corrupt", current_chunk, tabled_chunks);
           return FALSE;
         }
       }
@@ -606,7 +606,7 @@ BOOL LASreadPoint::read_chunk_table()
       // create error string
       if (last_error == 0) last_error = new CHAR[128];
       // report error
-      sprintf(last_error, "compressor was interrupted before writing adaptive chunk table of LAZ file");
+      snprintf(last_error, 128, "compressor was interrupted before writing adaptive chunk table of LAZ file");
       return FALSE;
     }
     // otherwise we build the chunk table as we read the file
@@ -621,7 +621,7 @@ BOOL LASreadPoint::read_chunk_table()
     // create warning string
     if (last_warning == 0) last_warning = new CHAR[128];
     // report warning
-    sprintf(last_warning, "compressor was interrupted before writing chunk table of LAZ file");
+    snprintf(last_warning, 128, "compressor was interrupted before writing chunk table of LAZ file");
     return TRUE;
   }
 
@@ -759,21 +759,21 @@ BOOL LASreadPoint::read_chunk_table()
       // report warning
       if (last_position == chunk_table_start_position)
       {
-        sprintf(last_warning, "chunk table is missing. improper use of LAZ compressor?");
+        snprintf(last_warning, 128, "chunk table is missing. improper use of LAZ compressor?");
       }
       else
       {
 #ifdef _WIN32
-        sprintf(last_warning, "chunk table and bytes are missing. LAZ file truncated during copy or transfer?");//, chunk_table_start_position - last_position);
+        snprintf(last_warning, 128, "chunk table and bytes are missing. LAZ file truncated during copy or transfer?");//, chunk_table_start_position - last_position);
 #else
-        sprintf(last_warning, "chunk table and bytes are missing. LAZ file truncated during copy or transfer?");//, chunk_table_start_position - last_position);
+        snprintf(last_warning, 128, "chunk table and bytes are missing. LAZ file truncated during copy or transfer?");//, chunk_table_start_position - last_position);
 #endif
       }
     }
     else
     {
       // report warning
-      sprintf(last_warning, "corrupt chunk table");
+      snprintf(last_warning, 128, "corrupt chunk table");
     }
   }
   if (!instream->seek(chunks_start))
